<?php
/**
 * Settings class
 *
 * @package notification
 */

namespace KreaLab\KLDebug\Admin;

use KreaLab\KLDebug\Utils\Settings\CoreFields;

/**
 * Settings class
 */
class Settings {

	/**
	 * Registers Example settings
	 *
	 * @param object $settings Settings API object.
	 *
	 * @return void
	 */
	public function general_settings( $settings ) {

		$general = $settings->add_section( __( 'General', 'kl_debug' ), 'general' );

		$group = $general->add_group( __( 'General', 'kl_debug' ), 'general' );

		$group->add_field( [
			'name'     => __( 'Display debug toolbar', 'kl_debug' ),
			'slug'     => 'display_debug_toolbar',
			'default'  => '',
			'value'    => 'true',
			'render'   => [ new CoreFields\Toggle(), 'input' ],
			'sanitize' => [ new CoreFields\Toggle(), 'sanitize' ],
		] );

		$group->add_field( [
			'name'     => __( 'Display Whoops panel', 'kl_debug' ),
			'slug'     => 'display_whoops_panel',
			'default'  => '',
			'value'    => 'true',
			'render'   => [ new CoreFields\Toggle(), 'input' ],
			'sanitize' => [ new CoreFields\Toggle(), 'sanitize' ],
		] );

		$group->add_field( [
			'name'     => __( 'Display debug toolbar for specific user', 'kl_debug' ),
			'slug'     => 'debug_toolbar_user_unlocking',
			'default'  => [],
			'addons'   => [
				'multiple' => true,
				'pretty'   => true,
				'options'  => $this->get_users()
			],
			'render'   => [ new CoreFields\Select(), 'input' ],
			'sanitize' => [ new CoreFields\Select(), 'sanitize' ],
		] );

	}

	/**
	 * Get user array for user select in settings.
	 *
	 * @return array
	 */
	public function get_users() {
		$users         = get_users();
		$user_sanitize = [];

		foreach ( $users as $user ) {
			$user_sanitize[ $user->ID ] = $user->display_name;
		}

		return $user_sanitize;
	}

}
