<?php

namespace KreaLab\KLDebug\Core;

use Whoops\Handler\PrettyPageHandler;
use Whoops\Run;

/**
 * Class Debug
 * @package KreaLab\KLDebug\Core
 */
class Debug {

	/**
	 * Debug var that contain all variables to display.
	 *
	 * @var array
	 */
	public $debug_vars = [];

	/**
	 * Debug constructor.
	 */
	public function __construct() {
		if(!is_admin()){
			// Register default variables
			$this->debug_vars = [
				'global' => [
					'title'      => __( 'Global variables', 'kl_debug' ),
					'parameters' => [
						'$_GET'    => $this->esc_variables( $_GET ),
						'$_POST'   => $this->esc_variables( $_POST ),
						'$_FILES'  => $this->esc_variables( $_FILES ),
						'$_SERVER' => $_SERVER,
					]
				]
			];
		}
	}
	
	/**
	 * Escape Variables or set default
	 *
	 * @param $variable
	 * @param $default
	 *
	 * @return mixed
	 */
	public function esc_variables( $variable, $default = [] ) {
		if( isset( $variable ) && !empty( $variable ) ) {
			return $this->array_map_recursive( 'esc_attr', $variable );
		}else {
			return $default;
		}
	}
	
	/**
	 * Recursive array map
	 *
	 * @param callable $func
	 * @param array    $array
	 *
	 * @return mixed
	 */
	private function array_map_recursive( callable $func, array $array ) {
		return filter_var( $array, \FILTER_CALLBACK, [ 'options' => $func ] );
	}

	/**
	 * Register Whoops error handlers.
	 *
	 * @action setup_theme
	 *
	 * @return void
	 */
	public function register_whoops() {
		$options = get_option( 'kl_debug_general', [] );
		
		if( empty( $options ) ) {
			return;
		}
		if ( isset( $options['general'], $options['general']['display_whoops_panel'] ) && 'true' === $options['general']['display_whoops_panel'] ) {
			$whoops = new Run();
			$whoops->prependHandler( new PrettyPageHandler() );
			$whoops->register();
		}
	}
	
	/**
	 * Add vars to toolbar.
	 *
	 * @action kl_debug/toolbar/add_var 10 3
	 *
	 * @param mixed  $var
	 * @param string $var_title
	 * @param string $section_title
	 * @param string $section_slug
	 */
	public function add_var( $var, $var_title, $section_title, $section_slug ) {
		
		$section_slug = sanitize_title( $section_title );

		$this->debug_vars[ $section_slug ]['title'] = $section_title;

		if ( empty( $var_title ) ) {
			$this->debug_vars[ $section_slug ]['parameters'][] = $var;
		} else {
			$this->debug_vars[ $section_slug ]['parameters'][ $var_title ] = $var;
		}
	}
}
