<?php
/**
 * Settings class
 *
 * @package krealab/kl_debug
 */

namespace KreaLab\KLDebug\Core;

use KreaLab\KLDebug\Utils\Settings as SettingsAPI;

/**
 * Settings class
 */
class Settings extends SettingsAPI {

	/**
	 * Settings constructor
	 */
	public function __construct() {
		parent::__construct( 'kl_debug' );
	}

	/**
	 * Registers Settings page under plugin's menu
	 *
	 * @action admin_menu 20
	 *
	 * @return void
	 */
	public function register_page() {

		$page_hooks = 'tools.php';
		$page_menu_label = __( 'KL Debug', 'kl_debug' );

		$this->page_hook = add_submenu_page( $page_hooks, $page_menu_label, $page_menu_label, 'manage_options', 'kl-debug-settings', [
				$this,
				'settings_page'
			] );

	}
	
	/**
	 * @filter plugin_action_links_kl-debug/kl-debug.php 20
	 */
	public function add_settings_link_in_plugins_page( $links )
	{
		// Build and escape the URL.
		$url = esc_url( add_query_arg(
			'page',
			'kl-debug-settings',
			get_admin_url() . 'tools.php'
		) );
		
		// Create the link.
		$settings_link = "<a href='$url'>" . __( 'Settings', 'kl_debug' ) . '</a>';
		
		// Adds the link to the end of the array.
		array_push(
			$links,
			$settings_link
		);
		
		return $links;
	}

	/**
	 * Registers Settings
	 *
	 * @action wp_loaded
	 *
	 * @return void
	 */
	public function register_settings() {
		do_action( 'kl_debug/settings/register', $this );
	}

}
