<?php

namespace Krealab\KLDebug\Front;

use KreaLab\KLDebug\Utils\Files;
use KreaLab\KLDebug\Utils\View;

/**
 * Class Toolbar
 * @package Krealab\KLDebug\Front
 */
class Toolbar {

	/**
	 * HTTP response code.
	 *
	 * @var int
	 */
	private $http_response_code;

	/**
	 * PHP memory limit.
	 *
	 * @var string
	 */
	private $php_memory_limit;

	/**
	 * Files class.
	 *
	 * @var Files
	 */
	private $files;

	/**
	 * View var.
	 *
	 * @var View
	 */
	private $view;

	/**
	 * Toolbar constructor.
	 *
	 * @param $files
	 */
	public function __construct( $files ) {
		$this->files = $files;

		$this->view = new View( $this->files );
	}

	/**
	 * Add toolbar
	 *
	 * @action wp_footer 100
	 */
	public function add_toolbar() {
		
		$options = get_option( 'kl_debug_general', [] );
		
		if ( empty( $options ) ) {
			return;
		}
		
		if ( isset( $options['general'], $options['general']['display_debug_toolbar'] ) && 'true' != $options['general']['display_debug_toolbar'] ) {
			return;
		}

		if ( isset( $options['general'], $options['general']['debug_toolbar_user_unlocking'] ) && ! empty( $options['general']['debug_toolbar_user_unlocking'] ) && ! in_array( get_current_user_id(), $options['general']['debug_toolbar_user_unlocking'] ) ) {
			return;
		}

		$this->http_response_code = http_response_code();

		$this->php_memory_limit = ini_get( 'this->php_memory_limit_limit' );
		// If we can't get it, fallback to WP_MEMORY_LIMIT.
		if ( ! $this->php_memory_limit || - 1 === $this->php_memory_limit ) {
			$this->php_memory_limit = wp_convert_hr_to_bytes( WP_MEMORY_LIMIT );
		}
		// Make sure the value is properly formatted in bytes.
		if ( ! is_numeric( $this->php_memory_limit ) ) {
			$this->php_memory_limit = wp_convert_hr_to_bytes( $this->php_memory_limit );
		}

		$this->view->set_var( 'page_load_duration', timer_stop( 0 ) );
		$this->view->set_var( 'http_response_code', $this->http_response_code );
		$this->view->set_var( 'http_response_color', $this->get_http_code_color( $this->http_response_code ) );
		$this->view->set_var( 'php_max_execution_time', ini_get( 'max_execution_time' ) );
		$this->view->set_var( 'php_memory_limit', $this->php_memory_limit );
		$this->view->set_var( 'user_infos', get_userdata( get_current_user_id() ) );

		$this->view->get_view( 'front/toolbar' );
	}

	/**
	 * Get HTTP color for response code.
	 *
	 * @param $code
	 *
	 * @return string
	 */
	public function get_http_code_color( $code ) {
		$color = 'kl-debug-toolbar-status ';
		if ( $code !== null ) {
			if ( $code < 300 ) {
				$color .= 'kl-debug-toolbar-status-green';
			} elseif ( $code < 400 ) {
				$color .= 'kl-debug-toolbar-status-yellow';
			} else {
				$color .= 'kl-debug-toolbar-status-red';
			}
		}

		return $color;
	}
}
