<?php
/**
 * Loader
 *
 * @package krealab/kl_debug
 */

namespace KreaLab\KLDebug;

use KreaLab\KLDebug\Utils;
use KreaLab\KLDebug\Admin;
use KreaLab\KLDebug\Core;

/**
 * Loader class
 */
class Loader extends Utils\DocHooks
{
	/**
	 * @var string
	 */
	private $plugin_file;

	/**
	 * @var bool
	 */
	private $plugin_custom_url;

	/**
	 * @var bool
	 */
	private $plugin_custom_path;

	/**
	 * @var Utils\Files
	 */
	public $files;

	/**
	 * @var Utils\i18n
	 */
	public $i18n;

	/**
	 * @var Core\Settings
	 */
	public $core_settings;

	/**
	 * @var Core\Debug
	 */
	public $core_debug;

	/**
	 * @var Admin\Settings
	 */
	public $admin_settings;

	/**
	 * @var Front\Toolbar
	 */
	public $front_toolbar;

	/**
	 * Class constructor
	 *
	 * @since 1.0.0
	 * @param string $plugin_file plugin main file full path.
	 */
	public function __construct($plugin_file)
	{
		$this->plugin_file        = $plugin_file;
		$this->plugin_custom_url  = defined('KLDEBUG_URL') ? KLDEBUG_URL : false;
		$this->plugin_custom_path = defined('KLDEBUG_DIR') ? KLDEBUG_DIR : false;
	}

	/**
	 * Loads needed files
	 *
	 * @since  1.0.0
	 * @return void
	 */
	public function boot()
	{
		$this->singletons();
		$this->load_functions();
		$this->actions();
	}

	/**
	 * Creates needed classes
	 * Singletons are used for a sake of performance
	 *
	 * @since  1.0.0
	 * @return void
	 */
	public function singletons()
	{
		$this->files                = new Utils\Files($this->plugin_file, $this->plugin_custom_url, $this->plugin_custom_path);
		$this->i18n 				= new Utils\i18n($this->files, 'kl_debug');

		$this->core_settings   		= new Core\Settings();
		$this->core_debug   		= new Core\Debug();

		$this->admin_settings   	= new Admin\Settings();

		$this->front_toolbar   	    = new Front\Toolbar($this->files);
	}

	/**
	 * All WordPress actions this plugin utilizes
	 *
	 * @since  1.0.0
	 * @return void
	 */
	public function actions()
	{
		$this->add_hooks($this->files);
		$this->add_hooks($this->i18n);

		$this->add_hooks($this->admin_settings);

		$this->add_hooks($this->core_settings);
		$this->add_hooks($this->core_debug);

		$this->add_hooks($this->front_toolbar);

		kl_debug_register_settings([$this->admin_settings, 'general_settings']);
	}

	/**
	 * Returns new View object
	 *
	 * @return Utils\View view object
	 * @since  1.0.0
	 */
	public function view()
	{
		return new Utils\View($this->files);
	}

	/**
	 * Loads functions
	 *
	 * @since  1.0.0
	 * @return void
	 */
	public function load_functions()
	{
		require_once $this->files->file_path( 'includes/functions/settings.php' );
		require_once $this->files->file_path( 'includes/functions/debug-function.php' );
	}

	/**
	 * Loads deprecated functions and classes
	 *
	 * @since  1.0.0
	 * @return void
	 */
	public function load_deprecated()
	{ }
}
