<?php
/**
 * i18n class
 * Loads plugin textdomain
 *
 * Since WordPress 4.6 translations are loaded via repository
 *
 * @package krealab/kl_debug
 */

namespace KreaLab\KLDebug\Utils;

use KreaLab\KLDebug\Utils\Files;

/**
 * Internationalization class
 */
class i18n
{

	/**
	 * Files class
	 *
	 * @var object
	 */
	protected $files;

	/**
	 * Textomain
	 *
	 * @var string
	 */
	protected $textdomain;

	/**
	 * Class constructor
	 *
	 * @param Files  $files      instance of Files object.
	 * @param string $textdomain textdomain string.
	 */
	public function __construct(Files $files, $textdomain)
	{
		$this->files      = $files;
		$this->textdomain = $textdomain;
	}

	/**
	 * Loads plugin textdomain
	 *
	 * @action plugins_loaded
	 *
	 * @return void
	 */
	public function load_textdomain()
	{
		load_plugin_textdomain($this->textdomain, false, $this->files->dir_path('languages'));
		// Traditional WordPress plugin locale filter
		// Uses get_user_locale() which was added in 4.7 so we need to check its available.
		if ( function_exists( 'get_user_locale' ) ) {
			$locale = apply_filters( 'plugin_locale', get_user_locale(), $this->textdomain );
		} else {
			$locale = apply_filters( 'plugin_locale', get_locale(), $this->textdomain );
		}

		//Setup paths to current locale file
		$mofile_global = trailingslashit( WP_LANG_DIR ) . 'plugins/kl-debug/' . $locale . '.mo';
		$mofile_local  = $this->files->dir_path('languages') . $locale . '.mo';

		if ( file_exists( $mofile_global ) ) {
			//Look in global /wp-content/languages/plugins/bb-plugin/ folder
			return load_textdomain( $this->textdomain, $mofile_global );
		} elseif ( file_exists( $mofile_local ) ) {
			//Look in local /wp-content/plugins/bb-plugin/languages/ folder
			return load_textdomain( $this->textdomain, $mofile_local );
		}

		//Nothing found
		return false;
	}

	/**
	 * Fixes admin strings returning
	 *
	 * @action init
	 *
	 * @return void
	 */
	public function load_native_admin_textdomain()
	{
		if (!is_admin()) {
			load_textdomain('default', WP_LANG_DIR . '/admin-' . get_locale() . '.mo');
		}
	}
}
