<?php
/**
 * Settings functions
 *
 * @package krealab/kl_debug
 */

/**
 * Registers settings
 *
 * @since  1.0.0
 * @param  mixed   $callback callback for settings registration, array of string.
 * @param  integer $priority action priority.
 * @return void
 */
function kl_debug_register_settings( $callback, $priority = 10 ) {

	if ( ! is_callable( $callback ) ) {
		trigger_error( 'You have to pass callable while registering the settings', E_USER_ERROR );
	}

	add_action( 'kl_debug/settings/register', $callback );

}

/**
 * Gets setting values
 *
 * @since 1.0.0
 * @return mixed
 */
function kl_debug_get_settings() {
	$loader = kl_debug_loader();
	return $loader->core_settings->get_settings();
}

/**
 * Gets single setting value
 *
 * @since  1.0.0
 * @param  string $setting setting name in `a/b/c` format.
 * @return mixed
 */
function kl_debug_get_setting( $setting ) {
	$loader = kl_debug_loader();
	return $loader->core_settings->get_setting( $setting );
}