<?php
/**
 * Plugin Name: KL Debug
 * Description: Add a Debug Bar to your Wordpress website to debug and develop your themes, plugins, etc...
 * Author: Krea'Lab
 * Author URI: https://www.krealab.fr
 * Version: 1.0.5
 * License: GPL3
 * Text Domain: kl_debug
 * Domain Path: /languages
 *
 * @package krealab/kl_debug
 */

use Micropackage\Requirements\Requirements;

define( 'KLDEBUG_VERSION', '1.0.5' );

if ( file_exists( dirname( __FILE__ ) . '/vendor/autoload.php' ) ) :
	require_once dirname( __FILE__ ) . '/vendor/autoload.php';
else :
	return false;
endif;

$requirements = new Requirements( __( 'KL Debug', 'kl_debug' ), [
	'php' => '7.2',
	'wp'  => '5.2',
] );

/**
 * Run all the checks and check if requirements has been satisfied.
 * If not - display the admin notice and exit from the file.
 */
if ( ! $requirements->satisfied() ) {
	$requirements->print_notice();
	return;
}

global $kl_debug_loader;

/**
 * Gets the plugin loader.
 *
 * @param string $property Optional property to get.
 *
 * @return object loader class instance
 */
function kl_debug_loader( $property = null ) {
	global $kl_debug_loader;

	if ( empty( $kl_debug_loader ) ) {
		$kl_debug_loader = new KreaLab\KLDebug\Loader( __FILE__ );
	}

	if ( null !== $property && isset( $kl_debug_loader->{$property} ) ) {
		return $kl_debug_loader->{$property};
	}

	return $kl_debug_loader;
}

$loader = kl_debug_loader();
$loader->boot();
